#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 Stream
version:              0.4.7.2
visibility:           public
id:                   Stream-0.4.7.2-DTMrsWmvtU85zQ5r5wErE4
key:                  Stream-0.4.7.2-DTMrsWmvtU85zQ5r5wErE4
license:              BSD-3-Clause
maintainer:           Wouter Swierstra <wouter.swierstra@gmail.com>
author:
    Wouter Swierstra <wouter.swierstra@gmail.com>
    Bas van Dijk <v.dijk.bas@gmail.com>

stability:            experimental
synopsis:             A library for manipulating infinite lists.
description:
    This package implements functions, analogous
    to those from Data.List, to create and manipulate
    infinite lists: @data Stream a = Cons a (Stream a)@.
    It provides alternative definitions for those
    Prelude functions that make sense for such streams.
    Note that this package has (almost)
    nothing to do with the work on /Stream Fusion/ by
    Duncan Coutts, Roman Leshchinskiy, and Don Stewart.

category:             Data
abi:                  2c247802e22e4aedc77bd3fc1b80e422
exposed:              True
exposed-modules:      Data.Stream
import-dirs:          /usr/lib/ghc-9.6.6/site-local/Stream-0.4.7.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/Stream-0.4.7.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/Stream-0.4.7.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-stream
hs-libraries:         HSStream-0.4.7.2-DTMrsWmvtU85zQ5r5wErE4
depends:
    QuickCheck-2.15.0.1-KbEu55Yn4v1JAMl6aurZE0 base-4.18.2.1
    lazysmallcheck-0.6-IWk82oVJh1K3AL7UYRy21R

haddock-interfaces:   /usr/share/doc/haskell-stream/html/Stream.haddock
haddock-html:         /usr/share/doc/haskell-stream/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

